@@ -1,5 +1,5 @@
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-#     Copyright (C) 2012 - 2018  Reza Mohammadi                                                    |
+#     Copyright (C) 2012 - 2019  Reza Mohammadi                                                    |
 #                                                                                                  |
 #     This file is part of BDgraph package.                                                        |
 #                                                                                                  |
@@ -49,10 +49,10 @@ bdgraph = function( data, n = NULL, method = "ggm", algorithm = "bdmcmc", iter =
 
 	if( is.data.frame( g.prior ) ) g.prior <- data.matrix( g.prior )
 	if( class( g.prior ) == "dtCMatrix" ) g.prior = as.matrix( g.prior )
-	if( ( class( g.prior ) == "bdgraph" ) | ( class( g.prior ) == "ssgraph" ) ) g.prior <- as.matrix( BDgraph::plinks( g.prior ) )
+	if( ( class( g.prior ) == "bdgraph" ) | ( class( g.prior ) == "ssgraph" ) ) g.prior <- BDgraph::plinks( g.prior )
 	if( class( g.prior ) == "sim" ) 
 	{
-	    K <- as.matrix( g.prior $ K )
+	    K       = as.matrix( g.prior $ K )
 	    g.prior = abs( K / diag( K ) )
 	}
 
@@ -72,13 +72,12 @@ bdgraph = function( data, n = NULL, method = "ggm", algorithm = "bdmcmc", iter =
 		
 	    if( is.null( not.cont ) )
 	    {
-	        not.cont = numeric( p )
+	        not.cont = c( rep( 1, p ) )
 	        for( j in 1:p )
-	            if( length( unique( data[ , j ] ) ) < min( 20, n / 2 ) ) not.cont[ j ] = 1
+	            if( length( unique( data[ , j ] ) ) > min( n / 2 ) ) not.cont[ j ] = 0
 	    }else{
 	        if( !is.vector( not.cont )  ) stop( " 'not.cont' must be a vector with length of number of variables" )
 	        if( length( not.cont ) != p ) stop( " 'not.cont' must be a vector with length of number of variables" )
-	        if( length( not.cont ) != p ) stop( " 'not.cont' must be a vector with length of number of variables" )
 	        if( ( sum( not.cont == 0 ) + sum( not.cont == 1 ) ) != p ) stop( " Element of 'not.cont', as a vector, must be 0 or 1" )
 	    }
 	    
@@ -135,8 +134,8 @@ bdgraph = function( data, n = NULL, method = "ggm", algorithm = "bdmcmc", iter =
 	
 	if( class( g.start ) == "sim" ) 
 	{
-		G <- as.matrix( unclass( g.start $ G ) )
-		K <- as.matrix( g.start $ K )
+		G <- unclass( g.start $ G )
+		K <- g.start $ K
 	} 
 	
 	if( class( g.start ) == "graph" ) G <- unclass( g.start )
@@ -255,8 +254,8 @@ bdgraph = function( data, n = NULL, method = "ggm", algorithm = "bdmcmc", iter =
 
 		if( ( method == "gcgm" ) && ( algorithm == "bdmcmc" ) && ( jump != 1 ) )
 		{
-		    not_continuous   = not.cont
-		    counter_all_g = 0
+		    not_continuous = not.cont
+		    counter_all_g  = 0
 			
 			result = .C( "gcgm_bdmcmc_map_multi_update", as.integer(iter), as.integer(burnin), G = as.integer(G), as.double(g_prior), as.double(Ts), K = as.double(K), as.integer(p), as.double(threshold),
 						as.double(Z), as.integer(R), as.integer(not_continuous), as.integer(n), as.integer(gcgm_NA),
@@ -362,7 +361,7 @@ bdgraph = function( data, n = NULL, method = "ggm", algorithm = "bdmcmc", iter =
 		if( ( method == "gcgm" ) && ( algorithm == "bdmcmc" ) && ( jump == 1 )  )
 		{
 		    not_continuous = not.cont
-		    
+
 		    result = .C( "gcgm_bdmcmc_ma", as.integer(iter), as.integer(burnin), G = as.integer(G), as.double(g_prior), as.double(Ts), K = as.double(K), as.integer(p), as.double(threshold),
 						as.double(Z), as.integer(R), as.integer(not_continuous), as.integer(n), as.integer(gcgm_NA),
 						K_hat = as.double(K_hat), p_links = as.double(p_links),
@@ -482,224 +481,134 @@ bdgraph = function( data, n = NULL, method = "ggm", algorithm = "bdmcmc", iter =
 }
       
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-#    Summary of bdgraph output                                                                     |
+#    Summary for the bdgraph boject                                                                |
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 summary.bdgraph = function( object, round = 2, vis = TRUE, ... )
 {
-	p_links    = object $ p_links
-	p          = nrow( object $ last_graph )
-	label      = colnames( object $ last_graph )
-	selected_g = matrix( 0, p, p, dimnames = list( label, label ) )	
+    K_hat      = object $ K_hat
+    p_links    = object $ p_links
+	if( is.null( p_links ) ) p_links = BDgraph::plinks( object )
 
-	if( !is.null( object $ graph_weights ) )
+    selected_g = BDgraph::select( p_links, cut = 0.5 )    
+
+	if( vis == TRUE )
 	{
-		sample_graphs = object $ sample_graphs
-		graph_weights = object $ graph_weights
-		max_gWeights  = max( graph_weights )
-		sum_gWeights  = sum( graph_weights )
-		max_prob_G    = max_gWeights / sum_gWeights
-
-		if ( is.null( label ) ) label <- as.character( 1 : p )
-		vec_G    <- c( rep( 0, p * ( p - 1 ) / 2 ) )		
-		indG_max <- sample_graphs[ which( graph_weights == max_gWeights ) ]
-		vec_G[ which( unlist( strsplit( as.character( indG_max ), "" ) ) == 1 ) ] = 1
-		selected_g[ upper.tri( selected_g ) ] <- vec_G 
-	}else{
-		selected_g[ p_links >  0.5 ] = 1
-		selected_g[ p_links <= 0.5 ] = 0
-	}
-
-	if( vis )
-	{
-		# plot selected graph (graph with the highest posterior probability)
-		G  <- igraph::graph.adjacency( selected_g, mode = "undirected", diag = FALSE )
-		 
 		if( !is.null( object $ graph_weights ) ) 
-		{
-			op       = graphics::par( mfrow = c( 2, 2 ), pty = "s", omi = c( 0.3, 0.3, 0.3, 0.3 ), mai = c( 0.3, 0.3, 0.3, 0.3 ) ) 
-			subGraph = paste( c( "Posterior probability = ", max_prob_G ), collapse = "" )
-		}else{
-			subGraph = "Selected graph with edge posterior probability = 0.5"
-		}
-			
+			op = graphics::par( mfrow = c( 2, 2 ), pty = "s", omi = c( 0.1, 0.1, 0.1, 0.1 ), mai = c( 0.3, 0.3, 0.3, 0.3 ) ) 
+		
+		p        = nrow( object $ last_graph )
+		subGraph = "Selected graph with edge posterior probability = 0.5"
 		if( p < 20 ) size = 15 else size = 2
+		
+		# - - - plot selected graph
+		G  <- igraph::graph.adjacency( selected_g, mode = "undirected", diag = FALSE )
 		igraph::plot.igraph( G, layout = igraph::layout.circle, main = "Selected graph", sub = subGraph, vertex.color = "white", vertex.size = size, vertex.label.color = 'black' )
 		
 		if( !is.null( object $ graph_weights ) )
 		{
-			# plot posterior distribution of graph
-			graphics::plot( x = 1 : length( graph_weights ), y = graph_weights / sum_gWeights, type = "h", main = "Posterior probability of graphs",
-				 ylab = "Pr(graph|data)", xlab = "graph" )
+		    sample_graphs = object $ sample_graphs
+		    graph_weights = object $ graph_weights
+		    sum_gWeights  = sum( graph_weights )
+		    
+		    # - - - plot posterior distribution of graph
+		    graph_prob = graph_weights / sum_gWeights
+			graphics::plot( x = 1 : length( graph_weights ), y = graph_prob, type = "h", main = "Posterior probability of graphs",
+				 ylab = "Pr(graph|data)", xlab = "graph", ylim = c( 0, max( graph_prob ) ) )
 			
-			graphics::abline( h = max_prob_G, col = "red" )
-			graphics::text( which( max_gWeights == graph_weights )[1], max_prob_G, "Pr(selected graph|data)", col = "gray60", adj = c( 0, +1 ) )
-			
-			# plot posterior distribution of graph size
+			# - - - plot posterior distribution of graph size
 			sizesample_graphs = sapply( sample_graphs, function( x ) length( which( unlist( strsplit( as.character( x ), "" ) ) == 1 ) ) )
 			xx       <- unique( sizesample_graphs )
 			weightsg <- vector()
 
-			for( i in 1 : length( xx ) ) weightsg[i] <- sum( graph_weights[ which( sizesample_graphs == xx[i] ) ] )
+			for( i in 1 : length( xx ) ) weightsg[ i ] <- sum( graph_weights[ which( sizesample_graphs == xx[ i ] ) ] )
 
 			graphics::plot( x = xx, y = weightsg / sum_gWeights, type = "h", main = "Posterior probability of graphs size", ylab = "Pr(graph size|data)", xlab = "Graph size" )
 
-			# plot trace of graph size
+			# - - - plot trace of graph size
 			all_graphs     = object $ all_graphs
 			sizeall_graphs = sizesample_graphs[ all_graphs ]
 			  
 			graphics::plot( x = 1 : length( all_graphs ), sizeall_graphs, type = "l", main = "Trace of graph size", ylab = "Graph size", xlab = "Iteration" )
-			
-			graphics::abline( h = sum( selected_g ), col = "red" )	  
-			
+
 			graphics::par( op )
 		}
 	}
 	
-	# p_links
-	if( !is.null( object $ graph_weights ) )
-	{
-		pvec <- 0 * vec_G
-		for( i in 1 : length( sample_graphs ) )
-		{
-			which_edge       <- which( unlist( strsplit( as.character( sample_graphs[i] ), "" ) ) == 1 )
-			pvec[which_edge] <- pvec[which_edge] + graph_weights[i]
-		}
-		p_links                     <- 0 * selected_g
-		p_links[upper.tri(p_links)] <- pvec / sum_gWeights
-	}
-	
-	K_hat = object $ K_hat
-	
 	if( is.null( K_hat ) )			  
-		return( list( selected_g = Matrix::Matrix( selected_g, sparse = TRUE ), p_links = Matrix::Matrix( round( p_links, round ), sparse = TRUE ) ) )
+		return( list( selected_g = selected_g, p_links = round( p_links, round ) ) )
 	else
-		return( list( selected_g = Matrix::Matrix( selected_g, sparse = TRUE ), p_links = Matrix::Matrix( round( p_links, round ), sparse = TRUE ), K_hat = round( K_hat, round ) ) )
+		return( list( selected_g = selected_g, p_links = round( p_links, round ), K_hat = round( K_hat, round ) ) )
 }  
    
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-#    Plot for class bdgraph                                                                        |
+#    Plot function for the bdgraph boject                                                          |
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 plot.bdgraph = function( x, cut = 0.5, number.g = NULL, layout = layout.circle, ... )
 {
-	if( !is.matrix( x ) )
+    if( ( cut < 0 ) || ( cut > 1 ) ) stop( " Value of 'cut' must be between 0 and 1." )
+    
+ 	if( is.null( number.g ) )
 	{
-		if( is.null( number.g ) )
-		{
-		    if( ( cut < 0 ) || ( cut > 1 ) ) stop( " Value of 'cut' must be between 0 and 1." )
-		    
-		    p_links = x $ p_links
-		    if( is.null( p_links ) ) p_links = BDgraph::plinks( x )
-		    
-		    selected_g                   = 0 * p_links
-		    selected_g[ p_links > cut  ] = 1
-		    selected_g[ p_links <= cut ] = 0		
-		    
-		    G = igraph::graph.adjacency( selected_g, mode = "undirected", diag = FALSE )
-		    igraph::plot.igraph( G, layout = layout, main = "Selected graph", sub = paste0( "Edge posterior probability = ", cut ), ... )	   		
-		}else{
-		    
-		    if( is.null( x $ all_graphs ) ) stop( " 'x' must be an object of function 'bdgraph()' or 'ssgraph()' with option save = TRUE" )
-		    
-		    sample_graphs = x $ sample_graphs
-		    graph_weights = x $ graph_weights
-		    prob_G        = graph_weights / sum( graph_weights )
-		    sort_prob_G   = sort( prob_G, decreasing = TRUE )
-		    
-		    p             = nrow( x $ last_graph )
-		    label         = colnames( x $ last_graph )
-		    list_G        = replicate( number.g, matrix( 0, p, p, dimnames = list( label, label ) ), simplify = FALSE )
-		    vec_G         = c( rep( 0, p * ( p - 1 ) / 2 ) )
-		    
-		    if( number.g == 2 ) op <- graphics::par( mfrow = c( 1, 2 ), pty = "s" )
-		    if( number.g > 2 & number.g < 7 )  op <- graphics::par( mfrow = c( 2, number.g %% 2 + trunc( number.g / 2 ) ), pty = "s" )
-		    
-		    for( i in 1 : number.g )
-		    {
-		        if( number.g > 6 ) grDevices::dev.new()  
-		        indG_i <- sample_graphs[ which( prob_G == sort_prob_G[i] )[1] ]
-		        vec_G  <- 0 * vec_G
-		        vec_G[ which( unlist( strsplit( as.character(indG_i), "" ) ) == 1 ) ] <- 1
-		        list_G[[i]][ upper.tri( list_G[[i]] ) ] <- vec_G
-		        
-		        G    <- igraph::graph.adjacency( list_G[[i]], mode = "undirected", diag = FALSE )
-		        
-		        main <- ifelse( i == 1, "Graph with highest probability", paste( c( i, "th graph" ), collapse = "" ) )
-		        igraph::plot.igraph( G, layout = layout, main = main, sub = paste( c( "Posterior probability = ", 
-		                                                                      round( sort_prob_G[i], 6 ) ), collapse = "" ), ... )	   
-		    }
-		    
-		    if( number.g > 1 & number.g < 7 ) graphics::par( op )
-        }
-	}else{
-	        if( ( sum( x == 0 ) + sum( x == 1 ) ) != ( nrow( x ) ^ 2 ) ) stop( " Element of the first input object must be 0 or 1" )
+	    p_links = x $ p_links
+	    if( is.null( p_links ) ) p_links = BDgraph::plinks( x )
 	    
-			G = igraph::graph.adjacency( x, mode = "undirected", diag = FALSE )
-			igraph::plot.igraph( G, layout = layout, main = "Graph with highest posterior probability", ... )	   		
-	}
+	    selected_g = BDgraph::select( p_links, cut = cut )
+
+	    G = igraph::graph.adjacency( selected_g, mode = "undirected", diag = FALSE )
+	    igraph::plot.igraph( G, layout = layout, sub = paste0( "Edge posterior probability = ", cut ), ... )	   		
+	}else{
+	    
+	    if( is.null( x $ all_graphs ) ) stop( " 'x' must be an object of function 'bdgraph()' with option save = TRUE" )
+	    
+	    sample_graphs = x $ sample_graphs
+	    graph_weights = x $ graph_weights
+	    prob_G        = graph_weights / sum( graph_weights )
+	    sort_prob_G   = sort( prob_G, decreasing = TRUE )
+	    
+	    p             = nrow( x $ last_graph )
+	    label         = colnames( x $ last_graph )
+	    list_G        = replicate( number.g, matrix( 0, p, p, dimnames = list( label, label ) ), simplify = FALSE )
+	    vec_G         = c( rep( 0, p * ( p - 1 ) / 2 ) )
+	    
+	    if( number.g == 2 ) op <- graphics::par( mfrow = c( 1, 2 ), pty = "s" )
+	    if( number.g > 2 & number.g < 7 )  op <- graphics::par( mfrow = c( 2, number.g %% 2 + trunc( number.g / 2 ) ), pty = "s" )
+	    
+	    for( i in 1 : number.g )
+	    {
+	        if( number.g > 6 ) grDevices::dev.new()  
+	        indG_i <- sample_graphs[ which( prob_G == sort_prob_G[i] )[1] ]
+	        vec_G  <- 0 * vec_G
+	        vec_G[ which( unlist( strsplit( as.character(indG_i), "" ) ) == 1 ) ] <- 1
+	        list_G[[i]][ upper.tri( list_G[[i]] ) ] <- vec_G
+	        
+	        G    <- igraph::graph.adjacency( list_G[[i]], mode = "undirected", diag = FALSE )
+	        
+	        main <- ifelse( i == 1, "Graph with highest probability", paste( c( i, "th graph" ), collapse = "" ) )
+	        igraph::plot.igraph( G, layout = layout, main = main, sub = paste( c( "Posterior probability = ", 
+	                                                                      round( sort_prob_G[i], 6 ) ), collapse = "" ), ... )	   
+	    }
+	    
+	    if( number.g > 1 & number.g < 7 ) graphics::par( op )
+    }
 }
      
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-#    Print of the bdgraph output                                                                   |
+#    Print function for the bdgraph boject                                                         |
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-print.bdgraph = function( x, round = 2, ... )
+print.bdgraph = function( x, ... )
 {
-	if( !is.matrix( x ) )
-	{
-		p_links = x $ p_links
-		
-		if( !is.null( x $ graph_weights ) )
-		{
-			p              = nrow( x $ last_graph )
-			sample_graphs  = x $ sample_graphs
-			graph_weights  = x $ graph_weights
-			# selected graph
-			max_gWeights  = max( graph_weights )
-			sum_gWeights  = sum( graph_weights )
-			vec_G         = c( rep( 0, p * ( p - 1 ) / 2 ) )
-			indG_max      = sample_graphs[ which( graph_weights == max_gWeights )[1] ]
-			vec_G[ which( unlist( strsplit( as.character( indG_max ), "" ) ) == 1 ) ] = 1
+	p_links = x $ p_links
+	if( is.null( p_links ) ) p_links = BDgraph::plinks( x )
+	selected_g = BDgraph::select( p_links, cut = 0.5 )
 
-			label      = colnames( x $ last_graph )
-			selected_g = matrix( 0, p, p, dimnames = list( label, label ) )	
-			selected_g[upper.tri(selected_g)] = vec_G
-		
-		}else{
-			selected_g                   = 0 * p_links
-			selected_g[ p_links > 0.5 ]  = 1
-			selected_g[ p_links <= 0.5 ] = 0	
-		}
-		
-	}else{
-		selected_g = unclass( x )
-	}
+	cat( paste( "\n Adjacency matrix of selected graph \n" ), fill = TRUE )
+	print( selected_g )
 	
-	cat( paste( "" ), fill = TRUE )
-	cat( paste( "Adjacency matrix of selected graph" ), fill = TRUE )
-	cat( paste( "" ), fill = TRUE )
-	
-	if( !is.matrix( x ) )
-	{	
-	    Matrix::printSpMatrix( Matrix::Matrix( selected_g, sparse = TRUE ), col.names = TRUE, note.dropping.colnames = FALSE )
-		cat( paste( "" ), fill = TRUE )
-		cat( paste( "Size of selected graph = ", sum( selected_g ) ), fill = TRUE )
-	
-	}else{
-		print( selected_g )
-		cat( paste( "" ), fill = TRUE )
-		cat( paste( "Size of selected graph = ", sum( selected_g ) / 2 ), fill = TRUE )	
-	}
-
-	if( !is.matrix( x ) )
-	{
-		if( !is.null( x $ graph_weights ) )
-			cat( paste( "Posterior probability of selected graph = ", max_gWeights / sum_gWeights ), fill = TRUE )  
-		else
-			cat( paste( "Edge posterior probability of selected graph = ", 0.5 ), fill = TRUE )
-	}
-	
-	cat( paste( "" ), fill = TRUE )
+    cat( paste( "\n Edge posterior probability of the links \n" ), fill = TRUE )
+    print( round( p_links, 2 ) )
 } 
-   
+     
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 
 
 
